@@ -21,7 +21,7 @@
 
 #include "cgipaf_defs.h"
 
-main()
+int main()
 {
 #include "cgipaf_vars.h"
 #include "cgipaf_init.c"
@@ -259,14 +259,51 @@ main()
    /* test the new password if cracklib is enabled */
    
    if(enable_cracklib) {
-      if ((cp=get_sg_item(config_file,CFGSECTION,CFG_CRACKLIB_DICTPATH))!=NULL) {
-	 cracklib_dictpath=xmalloc(strlen(cp)+1);
-	 strcpy(cracklib_dictpath,cp);
-	 xfree(cp);
-	 write_log(LOG_INFO,7,"cracklib_dictpath set to \"%s\"",cracklib_dictpath);
+      	if ((cp=get_sg_item(config_file,CFGSECTION,CFG_CRACKLIB_DICTPATH))!=NULL) {
+	 	cracklib_dictpath=xmalloc(strlen(cp)+1);
+	 	strcpy(cracklib_dictpath,cp);
+	 	xfree(cp);
+	 	write_log(LOG_INFO,7,"cracklib_dictpath set to \"%s\"",cracklib_dictpath);
+      	}
+
+	/* vrfy that cracklib_dictpath is readable */
+
+      	if (cracklib_dictpath!=NULL) {
+
+		char *full_cracklib_dictpath;
+		FILE *fp;
+
+		full_cracklib_dictpath=xmalloc(strlen(cracklib_dictpath)+strlen(".pwi")+1);
+
+		strcpy(full_cracklib_dictpath,cracklib_dictpath);
+		strcat(full_cracklib_dictpath,".pwi");
+
+		if(!(fp=fopen(full_cracklib_dictpath,"r"))) {
+
+	 		write_log(LOG_INFO,6,"full_cracklib_dictpath \"%s\" is not readable clearing",full_cracklib_dictpath);
+			cracklib_dictpath=NULL;
+
+		}
+		else {
+
+			fclose(fp);
+
+		}
+
+
       }
+
+      /* running Fascistcheck is cracklib_dictpath is not empty */
+
       if (cracklib_dictpath!=NULL) {
-	 char const * const crack_msg = FascistCheck(newpass1,cracklib_dictpath);
+
+	 char const * crack_msg;
+	 write_log(LOG_INFO,7,"running FascistCheck");
+
+	 crack_msg = FascistCheck(newpass1,cracklib_dictpath);
+
+	 write_log(LOG_INFO,7,"FascistCheck done");
+
 	 if (0 != crack_msg) {
 	    options[16][1]=(char *) xmalloc(strlen(crack_msg)+1);
 	    strcpy(options[16][1],crack_msg);
@@ -289,7 +326,7 @@ main()
    if ((brol=chpw(pw,newpass1))==PASS_SUCCESS) {
       show_msgs(config_file,doc_root,CFGSECTION,msg_success,msg_changed,options,txt_message);
       fflush(stdout);
-      write_log(LOG_AUTHPRIV,6,"Password for %s was changed",name);
+      write_log(LOG_AUTHPRIV,6,"Password for %s updated",name);
       options[15][1]=newpass1;
 
       /*
