@@ -19,8 +19,7 @@
  *
  */
 
-#include "config.h"
-#include <stdlib.h>
+#include "common.h"
 #ifdef HAVE_SYS_SYSTEMINFO_H
 #include <sys/systeminfo.h>
 #endif
